@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model-TkUI
 #
-# This software is Copyright (c) 2015 by Dominique Dumont.
+# This software is Copyright (c) 2016 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::CheckListEditor;
-$Config::Model::Tk::CheckListEditor::VERSION = '1.350';
+$Config::Model::Tk::CheckListEditor::VERSION = '1.352';
 use strict;
 use warnings;
 use Carp;
@@ -181,7 +181,7 @@ sub move_selected_up {
 
     $cw->{leaf}->move_up($name);
 
-    $cw->reload_tree;
+    $cw->{store_cb}->();
 }
 
 sub move_selected_down {
@@ -204,7 +204,7 @@ sub move_selected_down {
 
     $cw->{leaf}->move_down($name);
 
-    $cw->reload_tree;
+    $cw->{store_cb}->();
 }
 
 sub store {
@@ -243,9 +243,5 @@ sub reset_value {
     $cw->{help} = '';
 }
 
-sub reload_tree {
-    my $cw = shift;
-    $cw->parent->parent->parent->parent->reload();
-}
 
 1;
