@@ -1,18 +1,19 @@
 #
 # This file is part of Config-Model-TkUI
 #
-# This software is Copyright (c) 2015 by Dominique Dumont.
+# This software is Copyright (c) 2016 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::LeafViewer;
-$Config::Model::Tk::LeafViewer::VERSION = '1.350';
+$Config::Model::Tk::LeafViewer::VERSION = '1.352';
 use strict;
 use warnings;
 use Carp;
 use Log::Log4perl;
+use Text::Diff;
 
 use base qw/Tk::Frame Config::Model::Tk::AnyViewer/;
 
@@ -53,7 +54,8 @@ sub Populate {
     my $lv_frame = $cw->Frame(qw/-relief raised -borderwidth 2/)->pack(@pack_args);
     $lv_frame->Label( -text => 'Value' )->pack();
 
-    if ( $vt eq 'string' ) {
+    my $std = $cw->{leaf}->fetch_standard ;
+    if ( $vt eq 'string' and $std) {
         require Tk::ROText;
         $cw->{e_widget} = $lv_frame->Scrolled(
             'ROText',
@@ -62,6 +64,22 @@ sub Populate {
         )->pack(@fbe1);
         $cw->{e_widget}->insert( 'end', $v, 'value' );
         $cw->{e_widget}->tagConfigure(qw/value -lmargin1 2 -lmargin2 2 -rmargin 2/);
+
+        $lv_frame->Label( -text => 'Diff compared to standard value' )->pack();
+        $cw->{diff_widget} = $lv_frame->Scrolled(
+            'ROText',
+            -height     => 5,
+            -scrollbars => 'ow',
+        )->pack(@fbe1);
+
+        # Text::Diff does not handle well files without trailing \n
+        $std .= "\n" unless $std =~ /\n$/;
+        my $new = $v // '';
+        $new .= "\n" unless $new =~ /\n$/;
+
+        my $diff = diff( \$std, \$new , { STYLE => "Unified" } );
+        $cw->{diff_widget}->insert( 'end', $diff, 'value' );
+        $cw->{diff_widget}->tagConfigure(qw/value -lmargin1 2 -lmargin2 2 -rmargin 2/);
     }
     else {
         my $v_frame = $lv_frame->Frame(qw/-relief sunken -borderwidth 1/)->pack(@fxe1);
