@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-TkUI
 #
-# This software is Copyright (c) 2015 by Dominique Dumont.
+# This software is Copyright (c) 2016 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -10,7 +10,7 @@
 # copyright at the end of the file in the pod section
 
 package Config::Model::TkUI;
-$Config::Model::TkUI::VERSION = '1.350';
+$Config::Model::TkUI::VERSION = '1.352';
 use 5.10.1;
 use strict;
 use warnings;
@@ -234,8 +234,8 @@ sub Populate {
         $cw->on_select($item);
     };
 
-    $cw->bind( '<Return>', $b3_sub );
-    $cw->bind( '<Button-3>', $b3_sub );
+    $tree->bind( '<Return>', $b3_sub );
+    $tree->bind( '<Button-3>', $b3_sub );
     bind_clicks($tree,$b1_sub, $b3_sub);
 
     # bind button2 to get cut buffer content and try to store cut buffer content
@@ -245,9 +245,9 @@ sub Populate {
     };
     $tree->bind( '<Button-2>', $b2_sub );
 
-    $cw->bind( '<Control-c>', sub { $cw->edit_copy } );
-    $cw->bind( '<Control-v>', sub { $cw->edit_paste } );
-    $cw->bind( '<Control-f>', sub { $cw->pack_find_widget } );
+    $tree->bind( '<Control-c>', sub { $cw->edit_copy } );
+    $tree->bind( '<Control-v>', sub { $cw->edit_paste } );
+    $tree->bind( '<Control-f>', sub { $cw->pack_find_widget } );
 
     # bind button2 to get cut buffer content and try to store cut buffer content
     #my $key_sub = sub{my $item = $tree->nearest($tree->pointery - $tree->rooty) ;
@@ -460,16 +460,17 @@ sub save {
                 -title => 'Save error',
                 -text  => ref($@) ? $@->as_string : $@,
             )->Show;
+            $cb->($@); # indicate failure
         }
         else {
             $cw->show_message("Save done ...");
+            $cb->();
         }
-        $cb->();
     };
 
     $cw->show_message("Saving... please wait ...");
 
-    # use a short to let tk show the message above and then save
+    # use a short delay to let tk show the message above and then save
     $cw->after(100, $save_job) ;
 
 }
@@ -872,10 +873,19 @@ sub disp_check_list {
 
     my $value = $leaf_object->fetch;
 
-    $cw->{tktree}->itemCreate( $path, 2, -text => $cw->trim_value($value) );
+    my $tkt = $cw->{tktree};
+    $tkt->itemCreate( $path, 2, -text => $cw->trim_value($value) );
 
     my $std_v = $leaf_object->fetch('standard');
-    $cw->{tktree}->itemCreate( $path, 3, -text => $cw->trim_value($std_v) );
+    $tkt->itemCreate( $path, 3, -text => $cw->trim_value($std_v) );
+
+    if ( $std_v ne $value ) {
+        $tkt->itemCreate( $path, 1, -itemtype => 'image', -image => $cust_img );
+    }
+    else {
+        # remove image when value is identical to standard value
+        $tkt->itemDelete( $path, 1 ) if $tkt->itemExists( $path, 1 );
+    }
 }
 
 sub disp_leaf {
@@ -1338,6 +1348,14 @@ The wizard will scan the configuration tree and stop on all items
 flagged as important in the model. It will also stop on all erroneous
 items (mostly missing mandatory values).
 
+=head1 Methods
+
+=head2 save(callback)
+
+Save modified data in configuration file. The callback function is
+called only if the save was done without error. The callback is called
+with C<$@> in case of failed save.
+
 =head1 TODO
 
 - add tabular view ?
@@ -1346,10 +1364,6 @@ items (mostly missing mandatory values).
   can be used for some config Class (Could be handy for
   Xorg::ServerLayout)
 
-=head1 AUTHOR
-
-Dominique Dumont, (ddumont at cpan dot org)
-
 =head1 More information
 
 =over
@@ -1368,27 +1382,6 @@ Send a mail to Config::Model user mailing list: config-model-users at lists.sour
 
 =back
 
-=head1 LICENSE
-
-    Copyright (c) 2008-2012 Dominique Dumont.
-
-    This file is part of Config-Model.
-
-    Config-Model is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public License as
-    published by the Free Software Foundation; either version 2.1 of
-    the License, or (at your option) any later version.
-
-    Config-Model is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public License
-    along with Config-Model; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-    02110-1301 USA
-
 =head1 FEEDBACK and HELP wanted
 
 This project needs feedback from its users. Please send your
